/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.tools.ant;

import org.apache.tools.ant.taskdefs.Cvs;
import org.junit.Test;

public class XmlLoggerTest {

    /**
     * "NPE in XmlLogger.buildFinished"
     *
     * @see <a href="https://issues.apache.org/bugzilla/show_bug.cgi?id=56850">bug 56850</a>
     */
    @Test
    public void test() {
        final XmlLogger logger = new XmlLogger();
        final Cvs task = new Cvs();
        final BuildEvent event = new BuildEvent(task);
        logger.buildStarted(event);
        logger.buildFinished(event);
      }

}
